SystemOrganization addCategory: #'Cormas-Tests'!

TestCase subclass: #CMEntityTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Cormas-Tests'!

!CMEntityTest commentStamp: '<historical>' prior: 0!
A CormasEntityTest is a test class for testing the behavior of CormasEntity!

!CMEntityTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/1/2016 19:51'!
testCormasEntityIsAbstract
	self assert: CMEntity isAbstract! !

TestCase subclass: #CormasModelTest
	instanceVariableNames: 'conwayModel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Cormas-Tests'!

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 8/16/2017 18:50'!
testACellInConwayModelIsAtDistanceOneToAnotherCell
	| model oneCell |
	model := CMConwayModel
		initialize;
		new.
	model initSimulation.
	oneCell := (model allTheEntities: CMConwayCell) atRandom.
	self assert: (oneCell shortestDistanceToCellsVerifying: [ :c | c state = #dead | (c state = #alive) ]) equals: 1! !

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/30/2018 15:41'!
testAfterInitializationAConwayModelHas10000Cells
	| model |
	model := CMConwayModel
		initialize;
		new.
	model initSimulation.
	self assert: (model allTheEntities:CMConwayCell) size == 10000! !

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/30/2018 15:41'!
testAfterInitializationAConwayModelHas10000Entities
	| model |
	model := CMConwayModel
		initialize;
		new.
	model initSimulation.
	self assert: model allTheEntities size == 10000! !

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 8/16/2017 18:22'!
testConwayModelHasNoSocialEntityClass
	self assert: CMConwayModel socialClasses isEmpty! !

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/1/2016 20:07'!
testConwayModelHasOnlyOneSpatialEntityClass
	self assert: CMConwayModel spatialClasses size == 1! !

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/30/2018 15:44'!
testDominanceOfAModelIsLessThanOne
	| choosenModel aModel |
	choosenModel := CMFireAutomataModel.
	aModel := choosenModel
		initialize;
		new.
	aModel class defaultInit: #init58WithFire.
	aModel initializeSpaceModel.
	aModel
		createGridX: 100
		Y: 100
		neighbourhood: 4
		closed: true.
	aModel initSimulation.
	self assert: (aModel dominance: #state) < 1.0! !

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 8/16/2017 18:22'!
testECECModelHasThreeProbes
	self assert: CMECECModel probes size equals: 3! !

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/3/2016 14:58'!
testModelOfFireAutomataCellReturnFireAutomata
	self assert: CMFireAutomataCell modelClass == CMFireAutomataModel! !

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/30/2018 18:08'!
testNumberOfDifferentStateInAFireAutomataIsThree
	| choosenModel aModel |
	choosenModel := CMFireAutomataModel.
	aModel := choosenModel
		initialize;
		new.
	aModel class defaultInit: #init58WithFire.
	aModel initializeSpaceModel.
	aModel
		createGridX: 10
		Y: 10
		neighbourhood: 4
		closed: true.		
	aModel initSimulation.
	self assert: (aModel nbDistinctValuesOf: #state) equals: 3! !

!CormasModelTest methodsFor: 'tests' stamp: 'NicolasBecu 5/2/2018 00:34'!
testSizeOfCellsColumnOfFireAutomataModelIsTen
	| choosenModel aModel |
	choosenModel := CMFireAutomataModel.
	aModel := choosenModel
		initialize;
		new.
	aModel initializeSpaceModel.
	aModel
		createGridX: 10
		Y: 10
		neighbourhood: 4
		closed: true.
	aModel activeInit: #init58WithFire.
	aModel initSimulation.
	self assert: (aModel selectCellsOfColumn: 1) size equals: 10! !

!CormasModelTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/1/2016 20:07'!
testThereIsTwoClassesInConwayPackage
	self assert: CMConwayModel allClassesInPackage size == 2! !

!CormasModelTest methodsFor: 'tests' stamp: 'NicolasBecu 5/3/2018 17:41'!
testWhenThereIsNoNearestCell
	| model oneCell |
	model := CMConwayModel
		initialize;
		new.
	model activeInit: #initSmallGrid.
	model initSimulation.
	oneCell := (model allTheEntities: CMConwayCell) atRandom.
	self
		should: [ oneCell shortestDistanceToCellsVerifying: [ :c | c state = #zork ] ]
		raise: Error! !

TestCase subclass: #CormasOpenMoleTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Cormas-Tests'!

!CormasOpenMoleTest commentStamp: '<historical>' prior: 0!
plop!

!CormasOpenMoleTest class methodsFor: 'examples' stamp: 'EtienneDelay 5/30/2018 23:24'!
createInJSONFile
	"Create a JSON file for example 8"

	| stream |
	stream := FileStream forceNewFileNamed: 'input.json'.
	stream nextPutAll: self inJSON.
	stream close! !

!CormasOpenMoleTest class methodsFor: 'examples' stamp: 'EtienneDelay 5/30/2018 23:20'!
inJSON
	"Use in example8"

	^ '{
    "numberOfFires": 3,
	"numberOfFiremen": 20,
	"percentageOfTrees": 0.65,
	"dimensionMin": 60, 
	"dimensionMax": 80
}
'! !

!CormasOpenMoleTest methodsFor: 'test' stamp: 'EtienneDelay 5/30/2018 23:50'!
testLoadJSONFile
	| conf verif |
	CormasOpenMoleTest createInJSONFile.	"create a json file"
	conf := CMOpenMoleExchange loadJSONFile: 'input.json'.
	verif := Dictionary
		newFrom:
			{('dimensionMax' -> 80).
			('dimensionMin' -> 60).
			('numberOfFiremen' -> 20).
			('numberOfFires' -> 3).
			('percentageOfTrees' -> 0.65)}.
	self assert: (conf at: #dimensionMax) == (verif at: #dimensionMax)! !

TestCase subclass: #CormasTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Cormas-Tests'!

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:01'!
testAverage
	| n |
	n := #(1 2 3 4 5 6 7 8 9 10).
	self assert: (Cormas average: n) equals:  5.5.! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/21/2015 16:38'!
testCormasIsASingleton
	self assert: Cormas current == Cormas current! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:00'!
testCountInto
	| n |
	n := #(1 2 3 4 5 6 7 8 8 8 8 8 ).
	self assert: (Cormas count: 8 into: n) equals: 5.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/19/2018 19:24'!
testDropBlanksFromString
	| n |
	n := 'I Love Smalltalk'.
	self assert: (Cormas dropBlanksFromString: n) equals: 'ILoveSmalltalk'.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:00'!
testGiniIndex
"in R with ineq package c(10,20,58,96,48,76,57,68,19,10), return
[1] 0.3471861
Cormas giniIndexOf: #(10 20 58 96 48 76 57 68 19 10) => 34.71861
ok
"
	| n |
	n := #(10 20 58 96 48 76 57 68 19 10).
	self assert: (Cormas giniIndexOf: n) equals: 8020/231! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:00'!
testInterquartileRange
"in R with IQR(c(0,10,20,58,96,48,76,57,68,19,10), type = 1), return
[1] 58"
	| n |
	n := #(10 20 58 96 48 76 57 68 19 10).
	self assert: (Cormas interquartileRange: n) equals: 49.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:08'!
testLogisticGrowthRK
	self assert: (Cormas logisticIncrease: 1.0 r: 2.0 K: 4.0) equals: 1.5.
	self assert: (Cormas logisticGrowth: 1.0 r: 2.0 K: 4.0) equals: 2.5! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/19/2018 19:25'!
testLowerCaseFirstChar
	| n |
	n := 'I Love Smalltalk'.
	self assert: (Cormas lowerCaseFirstChar: n) equals: 'i Love Smalltalk'.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/19/2018 19:26'!
testLowerCaseString
	| n |
	n := 'I Love Smalltalk'.
	self assert: (Cormas lowerCaseString: n) equals: 'i love smalltalk'.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:00'!
testLowerQuartile
"in R with quantile(c(10,20,58,96,48,76,57,68,19,10), type = 1), return
	0%  25%  50%  75% 100% 
  10   19   48   68   96
upper quartile, is the value that cuts off the first 75%
"	
	|n|
	n := #(10 20 58 96 48 76 57 68 19 10).
	self assert: (Cormas lowerQuartile: n) equals: 19! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 21:59'!
testMax
	| n |
	n := #(10 20 58 96 48 76 57 68 19 10).
	self assert: (Cormas max: n) equals: 96! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 8/16/2017 18:23'!
testMaximumOfNumbers
	| aCollection |
	aCollection := #(3 1 5 4 2).
	self assert: (Cormas max: aCollection) equals: 5! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 21:59'!
testMedian
"in R with median(c(10,20,58,96,48,76,57,68,19,10)), return
[1] 52.5
"
	| n |
	n := #(10 20 58 96 48 76 57 68 19).
	self assert: (Cormas median: n) equals: 57.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:01'!
testMin
	| n |
	n := #(10 20 58 96 48 76 57 68 19 10).
	self assert: (Cormas min: n) equals: 10. ! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 8/16/2017 18:23'!
testMinimumOfNumbers
	| aCollection |
	aCollection := #(3 1 5 4 2).
	self assert: (Cormas min: aCollection) equals: 1! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/2/2015 20:23'!
testMixt
	| aCollection |
	aCollection := #(1 2 3 4 5).
	self assert: ((Cormas mixt: aCollection) includes: 1)! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:18'!
testMode
"in R
getmode <- function(v) {
   uniqv <- unique(v)
   uniqv[which.max(tabulate(match(v, uniqv)))]
}
getmode(c(10,20,58,96,48,76,57,68,19,10))

"
	| n |
	n := #(10 20 58 96 48 76 57 68 19 10).
	self assert: (Cormas mode: n) equals: #(10).! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/19/2018 19:30'!
testObjectTypeAsString
	
	self assert: (Cormas objectTypeAsString: 12) equals: '12'.
	self assert: (Cormas objectTypeAsString: true) equals: 'true'.! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/2/2015 20:35'!
testRandomBooleanReturnABoolean
	| aBoolean |
	aBoolean := Cormas randomBoolean.
	self assert: (aBoolean or: [ aBoolean not ])! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/16/2018 21:44'!
testRandomFloat
	| n |
	n := Cormas randomFloatFrom: -4.1 to: 2.5.
	self assert: n > -4.1 & (n < 2.5)! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/2/2015 20:35'!
testRandomReturnAValueBetweenZeroAndOne
	self assert: Cormas random > 0.
	self assert: Cormas random <= 1! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/19/2018 19:34'!
testRemoveFirstCharacterOfString
	
	self assert: (Cormas removeFirstCharacterOfString: 'Hello word') equals: 'ello word'.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:07'!
testRoundToNdigits
"In R round(4.8750654, digits = 2)
[1] 4.88
"
	self assert: (Cormas round: 4.8750654 toNdigits:  2) equals: 4.88. ! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/2/2015 20:35'!
testSelectRandomlyFrom
	| aCollection |
	aCollection := #(1 2 3 4 5).
	self assert: (aCollection includes: (Cormas selectRandomlyFrom: aCollection))! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:16'!
testSinMinMaxPhasePeriod
	"Not nice but ... work :-) I need to fin the way in R to build a true test"
	self assert: (Cormas sin: 3 min: -10 max: 20 phase: 0 period: 24) equals: 25.606601717798213 ! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/23/2018 17:21'!
testSortDecreasingly
	| n myblock|
	n := Cormas sortDecreasingly: #(10 20 58 96 48 76 57 68 19 10).
	myblock := n sortBlock.
	self assert: n equals: ((SortedCollection withAll: #(96 76 68 58 57 48 20 19 10 10)) sortBlock: myblock ).! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/23/2018 17:20'!
testSortIncreasingly
	| n myblock|
	n := Cormas sortIncreasingly: #(10 20 58 96 48 76 57 68 19 10).
	myblock := n sortBlock.
	self assert: n equals: ((SortedCollection withAll: #(10 10 19 20 48 57 58 68 76 96)) sortBlock: myblock).! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/18/2018 19:06'!
testStandardDeviation

	| n |
	n := #(10 20 58 96 48 76 57 68 19 10).
	self assert: (Cormas standardDeviation: n) equals: 28.547504269200136.! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 8/16/2017 18:23'!
testSumOfNumbers
	| aCollection |
	aCollection := #(3 1 5 4 2).
	self assert: (Cormas sum: aCollection) equals: 15! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 8/16/2017 18:23'!
testThereIsThreeRuntimeModes
	self assert: Cormas availableRuntimeModes size equals: 3! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/19/2018 20:51'!
testUpperCaseFirstChar
	
	self assert: (Cormas upperCaseFirstChar: 'hello world') equals: 'Hello world'.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/19/2018 20:52'!
testUpperCaseString
	
	self assert: (Cormas upperCaseString: 'Hello World') equals: 'HELLO WORLD'.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/17/2018 22:02'!
testUpperQuartile
"in R with quantile(c(10,20,58,96,48,76,57,68,19,10),type=1), return
  0%  25%  50%  75% 100% 
  10   19   48   68   96
upper quartile, is the value that cuts off the first 75%
"	
	|n|
	n := #(10 20 58 96 48 76 57 68 19 10).
	self assert: (Cormas upperQuartile: n) equals: 68.! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/18/2018 19:03'!
testVariance

	| n |
	n := #(10 20 58 96 48 76 57 68 19 10).
	self assert: (Cormas variance: n) equals: 814.96.! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/30/2018 14:31'!
testWhenAfterRunningTheModel20TimesTheProbesResultHaveTheSameSize
	| modelClass aModel nbSteps result |
	modelClass := CMFireAutomataModel.
	modelClass defaultInit: #init58WithFire.
	modelClass initialize.
	aModel := modelClass new.
	aModel initializeSpaceModel.
	aModel
		createGridX: 100
		Y: 100
		neighbourhood: 4
		closed: true.
	nbSteps := 20.
	aModel initSimulation.
	aModel pickCell isSpatialEntity.
	result := OrderedCollection new.
	nbSteps
		timesRepeat: [ aModel runStep.
			result add: aModel nbTrees ].
	self assert: result size equals: 20! !

!CormasTest methodsFor: 'tests' stamp: 'SergeStinckwich 4/30/2018 17:07'!
testWhenYouPickACellOfAModelThisIsASpatialEntity
	| modelClass aModel |
	modelClass := CMFireAutomataModel.
	"modelClass defaultInit: #init58WithFire."
	modelClass initialize.
	aModel := modelClass new.
	aModel initializeSpaceModel.
		aModel
		createGridX: 100
		Y: 100
		neighbourhood: 4
		closed: true.
	aModel initSimulation.
	self assert: aModel pickCell isSpatialEntity! !

!CormasTest methodsFor: 'tests' stamp: 'EtienneD 4/19/2018 19:35'!
teststringAsObjectType
	
	self assert: (Cormas stringAsObjectType: '12.3') equals: 12.3.! !

TestCase subclass: #CormasUITest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Cormas-Tests'!

!CormasUITest methodsFor: 'create CMProjet' stamp: 'NicolasBecu 5/6/2018 15:30'!
newProjectManagerWithInitializedUIOnModel: modelName
	| pWindow aProject simWindow |
	pWindow := CMSpecProjectWindow new.
	aProject := pWindow projectManager.
	simWindow := pWindow simWindow simWindow.
	simWindow
		translator: (CMTranslator newForLanguage: #EN);
		initialize.
	aProject openImageProject: modelName.
		aProject updateNewProject: 'CM' , modelName asString , 'Model'.
	^ aProject! !

!CormasUITest methodsFor: 'test' stamp: 'NicolasBecu 5/14/2018 00:15'!
testCanOpenModelFromImage
	| p |
	p := CMProjectManager new.
	p openImageProject: #CMConwayModel.
	self assert: p currentProject cormasModel class name equals: #CMConwayModel! !

!CormasUITest methodsFor: 'test' stamp: 'NicolasBecu 5/14/2018 00:13'!
testCurrentStepInputTextOfSimWindowIsResetAfterOpeningAModel
	| aCMProjectManager simWindow |
	aCMProjectManager := self newProjectManagerWithInitializedUIOnModel: #CMConwayModel.
	simWindow := aCMProjectManager projectWindow simWindow simWindow.
	
	20 timesRepeat: [ aCMProjectManager currentProject cormasModel runStep ].
	
	aCMProjectManager openImageProject: 'CMECECModel'.
	aCMProjectManager updateNewProject: 'CMECECModel'.
	self assert: simWindow currentStepInputText text equals: 0.! !

!CormasUITest methodsFor: 'test' stamp: 'NicolasBecu 5/14/2018 00:12'!
testCurrentStepInputTextOfSimWindowIsUpdatedWhenRuningSimulation
	| aCMProjectManager simWindow |
	aCMProjectManager := self newProjectManagerWithInitializedUIOnModel: #CMConwayModel.
	simWindow := aCMProjectManager projectWindow simWindow simWindow.
	simWindow openWithSpec.
	20 timesRepeat: [ aCMProjectManager currentProject cormasModel runStep ].
	self
		assert: simWindow currentStepInputText text
		equals: aCMProjectManager currentProject cormasModel timeStep. simWindow delete! !
